#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'

from zope.interface import Interface
from zope.schema import Bool, Choice
from zope.schema.vocabulary import SimpleTerm, SimpleVocabulary

from pyams_default_theme import _


FRAME_POSITIONS = (
    {'id': 'left', 'title': _("Left")},
    {'id': 'right', 'title': _("Right")},
    {'id': 'center', 'title': _("Center (full width)")}
)

FRAME_POSITIONS_VOCABULARY = SimpleVocabulary([SimpleTerm(item['id'], title=item['title'])
                                               for item in FRAME_POSITIONS])


class IVerbatimParagraphRendererSettings(Interface):
    """Verbatim paragraph renderer settings"""

    zoom_on_click = Bool(title=_("Zoom on image click?"),
                         description=_("If 'yes', a click on illustration thumbnail is required to zoom"),
                         required=True,
                         default=True)


class ILateralVerbatimParagraphRendererSettings(IVerbatimParagraphRendererSettings):
    """Verbatim paragraph lateral renderer settings interface"""

    relative_width = Choice(title=_("Relative width"),
                            description=_("Relative width used by this paragraph, relative to it's parent, "
                                          "given as columns count; full width counts for 12 columns"),
                            required=True,
                            values=list(range(1, 13)),
                            default=6)
